IMSI documentation
==================

The Integrated Modelling System Infrastructure (IMSI) ( /ɪm.ziː/ ) is a Python-based infrastructure and configuration framework for earth system modelling applications.

IMSI is developed and maintained by the Canadian Centre for Climate Modelling and Analysis (CCCma).

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   imsi
   usage
   developing_configurations
   ensemble
   imsi_tracking
   developing_imsi
   modules
   config_breaking_changes


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
